<?php
/**
 * @file
 * Contains \Drupal\noreferrer\Plugin\metatag\Tag\Referrer.
 */

namespace Drupal\noreferrer\Plugin\metatag\Tag;

use Drupal\Core\Annotation\Translation;
use Drupal\metatag\Plugin\metatag\Tag\MetaNameBase;
use Drupal\metatag\Annotation\MetatagTag;

/**
 * The referrer policy meta tag.
 *
 * @MetatagTag(
 *   id = "referrer",
 *   label = @Translation("Referrer policy"),
 *   description = @Translation("Using the <a href='https://w3c.github.io/webappsec-referrer-policy/#referrer-policy-delivery-meta'>referrer policy &lt;meta&gt; element</a>, a page can control the behavior of the Referer HTTP header attached to requests that originate from the page."),
 *   name = "referrer",
 *   group = "advanced",
 *   image = FALSE,
 *   multiple = FALSE
 * )
 */
class Referrer extends MetaNameBase {
  /**
   * {@inheritdoc}
   */
  public function form(array $element = []) {
    $form = [
      '#type' => 'select',
      '#title' => $this->label(),
      '#description' => $this->description(),
      '#options' => [
        'no-referrer' => t('No referrer'),
        'origin' => t('Origin'),
        'no-referrer-when-downgrade' => t('No referrer when downgrade'),
        'origin-when-cross-origin' => t('Origin when cross-origin'),
        'unsafe-url' => t('Unsafe URL'),
      ],
      '#empty_option' => t('- None -'),
      '#default_value' => $this->value,
    ];
    return $form;
  }
}
